@@ -142,10 +142,18 @@ var TabbrowserSessionManager = {
  
 	// datasource 
 	
+	get tabHistoryDataSource() 
+	{
+		if (!this._tabHistoryDataSource)
+			this._tabHistoryDataSource = this.service.getDataSource('history.rdf');
+		return this._tabHistoryDataSource;
+	},
+	_tabHistoryDataSource : null,
+	
 	get tabHistory() 
 	{
 		if (!this._tabHistory)
-			this._tabHistory = new pRDFDataR('TabsHistory', this.service.datasource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#');
+			this._tabHistory = new pRDFDataR('TabsHistory', this.tabHistoryDataSource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#');
 
 		if (this._tabHistory.length != this._tabHistory._resources.length)
 			this._tabHistory.reset();
@@ -157,7 +165,7 @@ var TabbrowserSessionManager = {
 	get tabHistoryQuitRoot() 
 	{
 		if (!this._tabHistoryQuitRoot)
-			this._tabHistoryQuitRoot = new pRDFDataR('TabsHistoryQuit', this.service.datasource.URI, 'bag', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
+			this._tabHistoryQuitRoot = new pRDFDataR('TabsHistoryQuit', this.tabHistoryDataSource.URI, 'bag', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
 
 		if (this._tabHistoryQuitRoot.length != this._tabHistoryQuitRoot._resources.length)
 			this._tabHistoryQuitRoot.reset();
@@ -169,7 +177,7 @@ var TabbrowserSessionManager = {
 	get tabHistoryQuit() 
 	{
 		if (!this._tabHistoryQuit)
-			this._tabHistoryQuit = new pRDFDataR('TabsHistoryQuit:window-'+Math.floor(Math.random() * 100000), this.service.datasource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
+			this._tabHistoryQuit = new pRDFDataR('TabsHistoryQuit:window-'+Math.floor(Math.random() * 100000), this.tabHistoryDataSource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
 
 		if (this._tabHistoryQuit.length != this._tabHistoryQuit._resources.length)
 			this._tabHistoryQuit.reset();
@@ -181,11 +189,19 @@ var TabbrowserSessionManager = {
 		this._tabHistoryQuit = aValue;
 	},
 	_tabHistoryQuit : null,
-  
+   
+	get tabsBackupDataSource() 
+	{
+		if (!this._tabsBackupDataSource)
+			this._tabsBackupDataSource = this.service.getDataSource('backup.rdf');
+		return this._tabsBackupDataSource;
+	},
+	_tabsBackupDataSource : null,
+	
 	get tabsBackupRoot() 
 	{
 		if (!this._tabsBackupRoot)
-			this._tabsBackupRoot = new pRDFDataR('TabsBackup', this.service.datasource.URI, 'bag', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
+			this._tabsBackupRoot = new pRDFDataR('TabsBackup', this.tabsBackupDataSource.URI, 'bag', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
 
 		if (this._tabsBackupRoot.length != this._tabsBackupRoot._resources.length)
 			this._tabsBackupRoot.reset();
@@ -197,7 +213,7 @@ var TabbrowserSessionManager = {
 	get tabsBackup() 
 	{
 		if (!this._tabsBackup)
-			this._tabsBackup = new pRDFDataR('TabsBackup:window-'+Math.floor(Math.random() * 100000), this.service.datasource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
+			this._tabsBackup = new pRDFDataR('TabsBackup:window-'+Math.floor(Math.random() * 100000), this.tabsBackupDataSource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
 
 		if (this._tabsBackup.length != this._tabsBackup._resources.length)
 			this._tabsBackup.reset();
@@ -209,11 +225,19 @@ var TabbrowserSessionManager = {
 		this._tabsBackup = aValue;
 	},
 	_tabsBackup : null,
-  
+   
+	get storedTabSetsDataSource() 
+	{
+		if (!this._storedTabSetsDataSource)
+			this._storedTabSetsDataSource = this.service.getDataSource('tabsessions.rdf');
+		return this._storedTabSetsDataSource;
+	},
+	_storedTabSetsDataSource : null,
+	
 	get storedTabSetsRoot() 
 	{
 		if (!this._storedTabSetsRoot)
-			this._storedTabSetsRoot = new pRDFDataR('StoredTabSets', this.service.datasource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
+			this._storedTabSetsRoot = new pRDFDataR('StoredTabSets', this.storedTabSetsDataSource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
 
 		if (this._storedTabSetsRoot.length != this._storedTabSetsRoot._resources.length)
 			this._storedTabSetsRoot.reset();
@@ -228,6 +252,14 @@ var TabbrowserSessionManager = {
 	
 	storedTabSets : [], 
    
+	get removeTabCacheDataSource() 
+	{
+		if (!this._removeTabCacheDataSource)
+			this._removeTabCacheDataSource = this.service.getDataSource('closedtabs.rdf');
+		return this._removeTabCacheDataSource;
+	},
+	_removeTabCacheDataSource : null,
+  
 	// prefs 
 	
 	get shouldResutoreLastVisitedTabs() 
@@ -246,6 +278,36 @@ var TabbrowserSessionManager = {
    
 	// Cxg̕ߑ 
 	
+	onBeforeInit : function() 
+	{
+		var oldDataFile = this.service.getFileFromURL(this.service.profileURL+'tabextensions.rdf');
+		if (!oldDataFile.exists()) return;
+
+		// inherit old datafile
+		var dataDir = this.service.getFileFromURL(this.service.profileURL+'tabextensions/');
+		if (!dataDir.exists()) {
+			dataDir.create(dataDir.DIRECTORY_TYPE, 0755);
+		}
+
+		var newFile;
+
+		newFile = this.service.getFileFromURL(this.service.profileURL+'tabextensions/tabsessions.rdf');
+		if (!newFile.exists())
+			oldDataFile.copyTo(dataDir, 'tabsessions.rdf');
+
+		newFile = this.service.getFileFromURL(this.service.profileURL+'tabextensions/backup.rdf');
+		if (!newFile.exists())
+			oldDataFile.copyTo(dataDir, 'backup.rdf');
+
+		newFile = this.service.getFileFromURL(this.service.profileURL+'tabextensions/closedtabs.rdf');
+		if (!newFile.exists())
+			oldDataFile.copyTo(dataDir, 'closedtabs.rdf');
+
+		newFile = this.service.getFileFromURL(this.service.profileURL+'tabextensions/history.rdf');
+		if (!newFile.exists())
+			oldDataFile.copyTo(dataDir, 'history.rdf');
+	},
+ 
 	onAfterInit : function() 
 	{
 		var nullPointer;
@@ -255,10 +317,17 @@ var TabbrowserSessionManager = {
 		nullPointer = this.storedTabSetsRoot;
 		delete nullPointer;
 
-		if (this.service.isBrowserWindow) {
+		var b = this.service.browser;
+		if (this.service.isBrowserWindow && b) {
 			this.service.addPrefListener(gTSMTabHistoryQuitPrefListener);
 			this.service.addPrefListener(gTSMTabsBackupPrefListener);
 
+			b.addEventListener('XULTabbrowserTabLoad', this.onXULTabbrowserTabLoad, false);
+			b.addEventListener('XULTabbrowserTabAdded', this.onXULTabbrowserTabAdded, false);
+			b.addEventListener('XULTabbrowserTabRemoved', this.onXULTabbrowserTabRemoved, false);
+			b.addEventListener('XULTabbrowserTabMoved', this.onXULTabbrowserTabMoved, false);
+//			b.addEventListener('XULTabbrowserTabGroupModified', this.onXULTabbrowserTabGroupModified, false);
+
 			gTSMTabHistoryQuitPrefListener.observe(null, 'nsPref:changed', null);
 			gTSMTabsBackupPrefListener.observe(null, 'nsPref:changed', null);
 		}
@@ -278,7 +347,7 @@ var TabbrowserSessionManager = {
 		if (!window.gTSGlobalUndoRemoveTabCache)
 			window.gTSGlobalUndoRemoveTabCache = [];
 		if (!window.gTSGlobalUndoRemoveTabCacheDatabase) {
-			window.gTSGlobalUndoRemoveTabCacheDatabase = new pRDFDataR('UndoRemoveTabCache', this.service.datasource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#');
+			window.gTSGlobalUndoRemoveTabCacheDatabase = new pRDFDataR('UndoRemoveTabCache', this.removeTabCacheDataSource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#');
 		}
 	},
  
@@ -326,61 +395,9 @@ try {
 				aArgumentIsDefaultStartup
 			)
 			) {
-			var shouldRestoreBackup = (this.tabsBackupRoot.length > this.service.browserWindows.length);
-			if (shouldRestoreBackup) {
-				shouldRestoreBackup = this.shouldBackupTabs;
-				var check = { value: this.service.getPref('browser.tabs.extensions.backup_tabs_confirm_hidden') };
-				if (!check.value) {
-					shouldRestoreBackup = this.service.PromptService.confirmEx(
-							window,
-							this.strbundle.GetStringFromName('message_restore_tabs_title'),
-							this.strbundle.GetStringFromName('message_restore_tabs_text'),
-							(
-								(this.service.PromptService.BUTTON_TITLE_YES * this.service.PromptService.BUTTON_POS_0) +
-								(this.service.PromptService.BUTTON_TITLE_NO * this.service.PromptService.BUTTON_POS_1)
-							),
-							null, null, null,
-							this.service.strbundle.GetStringFromName('message_never_show_dialog'),
-							check
-						) == 0;
 
-					// save pressed button
-					if (check.value) {
-						this.service.setPref('browser.tabs.extensions.backup_tabs_confirm_hidden', check.value);
-						this.service.setPref('browser.tabs.extensions.backup_tabs', shouldRestoreBackup);
-					}
+			var shouldRestoreBackup = this.checkShouldRestoreBackup();
 
-					// clear stored data
-					if (!shouldRestoreBackup) {
-						var history = this.tabsBackupRoot;
-
-						var res,
-							id,
-							entries = [];
-						for (var i = 0; i < history.length; i++)
-						{
-							id = history.item(i).Value.match(/TabsBackup:window-\d+/)[0];
-
-							if (id == this.tabsBackup.id) continue;
-
-							entries[i] = new pRDFDataR(id, this.datasource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
-						}
-
-						if (entries.length)
-							window.setTimeout(
-								function(aEntries)
-								{
-									for (var i in aEntries) {
-										aEntries[i].clearData();
-										TabbrowserService.tabsBackupRoot.removeData(aEntries[i].containerNode);
-									}
-								},
-								0,
-								entries
-							);
-					}
-				}
-			}
 			if (
 				this.shouldResutoreLastVisitedTabs ||
 				loadSelectedSession ||
@@ -470,8 +487,10 @@ try {
 				}
 			}
 
-			if (forceToRestore)
+			if (forceToRestore) {
 				this.service.setPref('browser.tabs.extensions.startup_action_overlay.one_time', false);
+				this.service.setPref('browser.tabs.extensions.startup_action_overlay', this.service.getPref('browser.tabs.extensions.startup_action_overlay.one_time.backup'));
+			}
 		}
 		else if ( // ŋ߃ANeBuuEUEBhE^uRs[
 			this.shouldResutoreLastVisitedTabs &&
@@ -482,10 +501,71 @@ try {
 		}
 }
 catch(e) {
-	if (this.service && this.service.debug) alert('in "TabbrowserService.initWithDelay()"\n\n'+e);
+	if (this.service && this.service.debug)
+		alert('@TabbrowserSessionManager.overlayStartupAction()\n'+e);
 }
 	},
-  
+	
+	checkShouldRestoreBackup : function() 
+	{
+		var shouldRestoreBackup = (this.tabsBackupRoot.length > this.service.browserWindows.length);
+		if (shouldRestoreBackup) {
+			shouldRestoreBackup = this.shouldBackupTabs;
+			var check = { value: this.service.getPref('browser.tabs.extensions.backup_tabs_confirm_hidden') };
+			if (!check.value) {
+				shouldRestoreBackup = this.service.PromptService.confirmEx(
+						window,
+						this.strbundle.GetStringFromName('message_restore_tabs_title'),
+						this.strbundle.GetStringFromName('message_restore_tabs_text'),
+						(
+							(this.service.PromptService.BUTTON_TITLE_YES * this.service.PromptService.BUTTON_POS_0) +
+							(this.service.PromptService.BUTTON_TITLE_NO * this.service.PromptService.BUTTON_POS_1)
+						),
+						null, null, null,
+						this.service.strbundle.GetStringFromName('message_never_show_dialog'),
+						check
+					) == 0;
+
+				// save pressed button
+				if (check.value) {
+					this.service.setPref('browser.tabs.extensions.backup_tabs_confirm_hidden', check.value);
+					this.service.setPref('browser.tabs.extensions.backup_tabs', shouldRestoreBackup);
+				}
+			}
+
+			if (!shouldRestoreBackup) { // clear stored data
+				var history = this.tabsBackupRoot;
+
+				var res,
+					id,
+					entries = [];
+				for (var i = 0; i < history.length; i++)
+				{
+					id = history.item(i).Value.match(/TabsBackup:window-\d+/)[0];
+
+					if (id == this.tabsBackup.id) continue;
+
+					entries[i] = new pRDFDataR(id, this.tabsBackupDataSource, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
+				}
+
+				if (entries.length)
+					window.setTimeout(
+						function(aEntries)
+						{
+							for (var i in aEntries) {
+								aEntries[i].clearData();
+								TabbrowserService.tabsBackupRoot.removeData(aEntries[i].containerNode);
+							}
+						},
+						0,
+						entries
+					);
+			}
+		}
+
+		return shouldRestoreBackup;
+	},
+   
 	onBeforeDestruct : function() 
 	{
 		var i;
@@ -533,10 +613,17 @@ catch(e) {
 			}
 		}
 
-		if (this.service.isBrowserWindow) {
+		var b = this.service.browser;
+		if (this.service.isBrowserWindow && b) {
 			this.service.removePrefListener(gTSMTabHistoryQuitPrefListener);
 			this.service.removePrefListener(gTSMTabsBackupPrefListener);
 
+			b.removeEventListener('XULTabbrowserTabLoad', this.onXULTabbrowserTabLoad, false);
+			b.removeEventListener('XULTabbrowserTabAdded', this.onXULTabbrowserTabAdded, false);
+			b.removeEventListener('XULTabbrowserTabRemoved', this.onXULTabbrowserTabRemoved, false);
+			b.removeEventListener('XULTabbrowserTabMoved', this.onXULTabbrowserTabMoved, false);
+//			b.removeEventListener('XULTabbrowserTabGroupModified', this.onXULTabbrowserTabGroupModified, false);
+
 			try {
 				this.service.ObserverService.removeObserver(gTSStoredTabSetsListener, 'tabextensions:storedTabSetsModified', false);
 			}
@@ -546,14 +633,12 @@ catch(e) {
 			window.removeEventListener('XULTabbrowserUndoCacheRemoved', this.onXULTabbrowserUndoCacheModified, true);
 		}
 
-		var b = this.service.browsers,
-			j;
-		if (this.service.getPref('browser.tabs.extensions.undo_cache.global')) {
-			for (i = 0; i < b.length; i++) {
-				if (!b[i].mTabs) continue; // if the browser has no 'mTabs' property, shutdown process wrongly stops on this point.
-				for (j = 0; j < b[i].mTabs.length; j++)
-					if (!b[i].mTabs[j].isReallyBlank)
-						this.updateGlobalUndoCache(b[i].getTabInfo(b[i].mTabs[j]), true);
+		if (b &&
+			this.service.getPref('browser.tabs.extensions.undo_cache.global')) {
+			if (b.mTabs) { // if the browser has no 'mTabs' property, shutdown process wrongly stops on this point.
+				for (i = 0; i < b.mTabs.length; i++)
+					if (!b.mTabs[i].isReallyBlank)
+						this.updateGlobalUndoCache(b.getTabInfo(b.mTabs[i]), true);
 			}
 		}
 
@@ -574,27 +659,39 @@ catch(e) {
 		window.gTSGlobalUndoRemoveTabCacheDatabase = null;
 	},
  
-	onTabLoad : function(aIndex) 
+	onXULTabbrowserTabLoad : function(aEvent) 
 	{
-		if (this.shouldBackupTabs)
-			this.saveTabAt(aIndex, this.tabsBackup);
+		if (TabbrowserSessionManager.shouldBackupTabs)
+			TabbrowserSessionManager.saveTabAt(aEvent.target.getTabByTabId(aEvent.tabId).tabIndex, TabbrowserSessionManager.tabsBackup);
 	},
  
-	onTabRemoved : function(aTabId) 
+	onXULTabbrowserTabAdded : function(aEvent) 
+	{
+		if (TabbrowserSessionManager.shouldBackupTabs)
+			TabbrowserSessionManager.saveTabAt(aEvent.target.getTabByTabId(aEvent.tabId).tabIndex, TabbrowserSessionManager.tabsBackup);
+	},
+ 
+	onXULTabbrowserTabGroupModified : function(aEvent) 
+	{
+		if (TabbrowserSessionManager.shouldBackupTabs)
+			TabbrowserSessionManager.saveTabAt(aEvent.target.getTabByTabId(aEvent.tabId).tabIndex, TabbrowserSessionManager.tabsBackup);
+	},
+ 
+	onXULTabbrowserTabRemoved : function(aEvent) 
 	{
 		// remove the entry from the history
-		if (this.shouldBackupTabs) {
-			var res = this.tabsBackup.getResource(aTabId);
-			this.removeSHEntriesFrom(res, this.tabsBackup);
-			this.tabsBackup.removeData(res);
+		if (TabbrowserSessionManager.shouldBackupTabs) {
+			var res = TabbrowserSessionManager.tabsBackup.getResource(aEvent.tabId);
+			TabbrowserSessionManager.removeSHEntriesFrom(res, TabbrowserSessionManager.tabsBackup);
+			TabbrowserSessionManager.tabsBackup.removeData(res);
 		}
 	},
  
-	onTabMoved : function(aTabId, aIndex) 
+	onXULTabbrowserTabMoved : function(aEvent) 
 	{
 		// move the entry for the tab
-		if (this.shouldBackupTabs)
-			this.tabsBackup.moveElementTo(aTabId, aIndex);
+		if (TabbrowserSessionManager.shouldBackupTabs)
+			TabbrowserSessionManager.tabsBackup.moveElementTo(aEvent.tabId, aEvent.target.getTabByTabId(aEvent.tabId).tabIndex);
 	},
  
 	// edit the global "undo close tab" cache when the cache in this window has been modified 
@@ -662,6 +759,18 @@ catch(e) {
 			'selected',           aInfo.selected,
 			'HistoryIndex',       aInfo.SHIndex,
 
+			'locked',             aInfo.locked,
+			'referrerBlocked',    aInfo.referrerBlocked,
+			'autoreloadInterval', String(aInfo.autoreloadInterval),
+			'autoreloadPostType', aInfo.autoreloadPostType,
+			'autoreloadPostData', this.service.escape(aInfo.autoreloadPostData || ''),
+
+			'allowPlugins',       aInfo.allowPlugins,
+			'allowJavascript',    aInfo.allowJavascript,
+			'allowMetaRedirects', aInfo.allowMetaRedirects,
+			'allowSubframes',     aInfo.allowSubframes,
+			'allowImages',        aInfo.allowImages,
+
 			'fixedLabel',         aInfo.fixedLabel,
 			'textZoom',           aInfo.textZoom,
 
@@ -774,7 +883,8 @@ try {
 		}
 }
 catch(e) {
-	if (this.service.debug) alert('in "TabbrowserService.saveSHEntriesFor()"\n\n'+e);
+	if (this.service.debug)
+		alert('@TabbrowserSessionManager.saveSHEntriesFor()\n'+e);
 }
 	},
  
@@ -808,7 +918,8 @@ try {
 		}
 }
 catch(e) {
-	if (this.service.debug) alert('in "TabbrowserSessionManager.removeSHEntriesFrom()"\n\n'+e);
+	if (this.service.debug)
+		alert('@TabbrowserSessionManager.removeSHEntriesFrom()\n'+e);
 }
 	},
   
@@ -826,6 +937,18 @@ catch(e) {
 			parentTab          : (aDatabase.getData(aRes, 'parentTab') || null),
 			childTabs          : [],
 
+			locked             : (aDatabase.getData(aRes, 'locked') == 'true'),
+			referrerBlocked    : (aDatabase.getData(aRes, 'referrerBlocked') == 'true'),
+			autoreloadInterval : Number(aDatabase.getData(aRes, 'autoreloadInterval')),
+			autoreloadPostType : aDatabase.getData(aRes, 'autoreloadPostType'),
+			autoreloadPostData : this.service.unescape(aDatabase.getData(aRes, 'autoreloadPostData') || ''),
+
+			allowPlugins       : (aDatabase.getData(aRes, 'allowPlugins') == 'true'),
+			allowJavascript    : (aDatabase.getData(aRes, 'allowJavascript') == 'true'),
+			allowMetaRedirects : (aDatabase.getData(aRes, 'allowMetaRedirects') == 'true'),
+			allowSubframes     : (aDatabase.getData(aRes, 'allowSubframes') == 'true'),
+			allowImages        : (aDatabase.getData(aRes, 'allowImages') == 'true'),
+
 			fixedLabel         : aDatabase.getData(aRes, 'fixedLabel'),
 			textZoom           : Number(aDatabase.getData(aRes, 'textZoom')),
 
@@ -899,7 +1022,8 @@ try {
 		}
 }
 catch(e) {
-	if (this.service.debug) alert('in "TabbrowserSessionManager.getSHEntriesFrom()"\n\n'+e);
+	if (this.service.debug)
+		alert('@TabbrowserSessionManager.getSHEntriesFrom()\n'+e);
 }
 		return entries;
 	},
@@ -934,7 +1058,8 @@ try {
 			this.saveTabAt(i, aDatabase);
 }
 catch(e) {
-	if (this.service.debug) alert('in "TabbrowserSessionManager.saveAllTabs()"\n\n'+e);
+	if (this.service.debug)
+		alert('@TabbrowserSessionManager.saveAllTabs()\n'+e);
 }
 	},
 	
@@ -963,7 +1088,8 @@ try {
 if (this.service.debug) dump('=>['+aIndex+'] '+info.uri.substr(0, 25)+' SAVED.\n');
 }
 catch(e) {
-	if (this.service.debug) alert('in "TabbrowserService.saveTabAt()"\n\n'+e);
+	if (this.service.debug)
+		alert('@TabbrowserSessionManager.saveTabAt()\n'+e);
 }
 	},
   
@@ -972,7 +1098,7 @@ catch(e) {
 	{
 		var doneCorrectly = true;
 try {
-		if (this.service.browsers.length < 1) return doneCorrectly;
+		if (!this.service.browser) return doneCorrectly;
 
 		if (!aDatabase || !aDatabase.length) return doneCorrectly;
 
@@ -988,7 +1114,7 @@ try {
 
 				if (id == this.tabsBackup.id) continue;
 
-				entries[i] = new pRDFDataR(id, this.service.datasource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
+				entries[i] = new pRDFDataR(id, this.tabsBackupDataSource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
 			}
 
 			if (entries.length)
@@ -1001,7 +1127,7 @@ try {
 
 				if (id == this.tabHistoryQuit.id) continue;
 
-				entries[i] = new pRDFDataR(id, this.service.datasource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
+				entries[i] = new pRDFDataR(id, this.tabHistoryDataSource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, true);
 			}
 
 			if (entries.length)
@@ -1019,7 +1145,8 @@ try {
 }
 catch(e) {
 		doneCorrectly = false;
-	if (this.service.debug) alert('in "TabbrowserSessionManager.restoreAllTabs()"\n\n'+e);
+	if (this.service.debug)
+		alert('@TabbrowserSessionManager.restoreAllTabs()\n'+e);
 }
 
 		// broken data
@@ -1050,7 +1177,7 @@ try {
 				doneFirst = true;
 			}
 
-			if (!TabbrowserSessionManager.restoreAllTabsFrom(aEntries[i], i == 0 ? b.selectedTab : null ))
+			if (!TabbrowserSessionManager.restoreAllTabsFrom(aEntries[i], i == 0 ? t : null ))
 				doneCorrectly = false;
 
 			for (j = aEntries[i].length-1; j > -1; j--)
@@ -1061,7 +1188,8 @@ try {
 }
 catch(e) {
 		doneCorrectly = false;
-	if (TabbrowserService.debug) alert('in "TabbrowserSessionManager.restoreAllTabsFromRoot()"\n\n'+e);
+	if (TabbrowserService.debug)
+		alert('@TabbrowserSessionManager.restoreAllTabsFromRoot()\n'+e);
 }
 
 		// broken data
@@ -1132,13 +1260,15 @@ if (this.service.debug) dump('<=['+i+'] '+info.uri.substr(0, 25)+' RESTORED.\n')
 }
 catch(e) {
 		doneCorrectly = false;
-	if (this.service.debug) alert('in "TabbrowserSessionManager.restoreAllTabsFrom()"\n'+res.Value+'\n\n'+e);
+	if (this.service.debug)
+		alert('@TabbrowserSessionManager.restoreAllTabsFrom()\n'+res.Value+'\n\n'+e);
 }
 		}
 }
 catch(ex) {
 		doneCorrectly = false;
-	if (this.service.debug) alert('in "TabbrowserSessionManager.restoreAllTabsFrom()"\n\n'+ex);
+	if (this.service.debug)
+		alert('@TabbrowserSessionManager.restoreAllTabsFrom()\n'+ex);
 }
 
 		if (errorOut.value) doneCorrectly = false;
@@ -1162,7 +1292,7 @@ catch(ex) {
 
 			if (!id) continue;
 
-			this.storedTabSets[id] = new pRDFDataR(id, this.service.datasource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, false);
+			this.storedTabSets[id] = new pRDFDataR(id, this.storedTabSetsDataSource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, false);
 		}
 	},
 	
@@ -1173,7 +1303,7 @@ catch(ex) {
 		var b = this.service.browser;
 		if ('replaceGroup' in b) {
 			var removedTabsInfo = [];
-			for (var i in b.mTabs)
+			for (var i = 0; i < b.mTabs.length; i++)
 				removedTabsInfo.push(b.getTabInfo(b.mTabs[i]));
 
 			b.backBrowserGroup    = removedTabsInfo;
@@ -1226,7 +1356,7 @@ catch(ex) {
 	saveTabSession : function(aShouldShowAlert) 
 	{
 		var id = 'StoredTabSets:tabset-'+Math.floor(Math.random() * 100000);
-		this.storedTabSets[id] = new pRDFDataR(id, this.service.datasource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, false);
+		this.storedTabSets[id] = new pRDFDataR(id, this.storedTabSetsDataSource.URI, 'seq', 'http://white.sakura.ne.jp/~piro/rdf#', 'chrome://tabextensions/content/tabextensions.rdf#', null, false);
 
 		var d     = new Date();
 		var label = this.strbundle.GetStringFromName('tabSetsHolder_label_for_new_session')
@@ -1261,7 +1391,7 @@ catch(ex) {
 		TSM.service.PromptService.alert(
 			window,
 			TSM.strbundle.GetStringFromName('tabSetsHolder_save_alert_title'),
-			TSM.strbundle.GetStringFromName('tabSetsHolder_save_alert_text')
+			TSM.strbundle.GetStringFromName('tabSetsHolder_save_alert_text').replace(/%s/i, aLabel)
 		);
 	},
   
@@ -1305,15 +1435,22 @@ catch(ex) {
 			del    = aPopup.getElementsByAttribute('tabid', 'delete')[0],
 			delAll = aPopup.getElementsByAttribute('tabid', 'deleteAll')[0];
 
-		while (aPopup.firstChild.localName == 'menuitem')
-			aPopup.removeChild(aPopup.firstChild);
+		var range = document.createRange();
 
-		while (full.firstChild.hasChildNodes())
-		{
-			full.firstChild.removeChild(full.firstChild.lastChild);
-			rename.firstChild.removeChild(rename.firstChild.lastChild);
-			del.firstChild.removeChild(del.firstChild.lastChild);
-		}
+		range.selectNodeContents(aPopup);
+		range.setEndBefore(full);
+		range.deleteContents();
+
+		range.selectNodeContents(full.firstChild);
+		range.deleteContents();
+
+		range.selectNodeContents(rename.firstChild);
+		range.deleteContents();
+
+		range.selectNodeContents(del.firstChild);
+		range.deleteContents();
+
+		range.detach();
 
 		var item,
 			count         = 0,
@@ -1391,9 +1528,8 @@ catch(ex) {
 			if (!('TabbrowserService' in window) ||
 				!target.TabbrowserService) continue;
 
-			b = target.TabbrowserService.browsers;
-			for (i = 0; i < b.length; i++)
-				b[i].mRemovedTabInfoList = [];
+			b = target.TabbrowserService.browser;
+			if (b) b.mRemovedTabInfoList = [];
 		}
 
 		for (i = gTSGlobalUndoRemoveTabCacheDatabase.length-1; i > -1; i--)
@@ -1458,11 +1594,16 @@ catch(ex) {
 			full   = aPopup.getElementsByAttribute('tabid', 'full')[0],
 			flush  = aPopup.getElementsByAttribute('tabid', 'flush-item')[0];
 
-		while (aPopup.firstChild != blank)
-			aPopup.removeChild(aPopup.firstChild);
+		var range = document.createRange();
 
-		while (full.firstChild.hasChildNodes())
-			full.firstChild.removeChild(full.firstChild.lastChild);
+		range.selectNodeContents(aPopup);
+		range.setEndBefore(blank);
+		range.deleteContents();
+
+		range.selectNodeContents(full.firstChild);
+		range.deleteContents();
+
+		range.detach();
 
 		var item,
 			list = gTSGlobalUndoRemoveTabCache;
@@ -1500,7 +1641,7 @@ catch(ex) {
 			full.setAttribute('hidden', true);
 	},
   
-	confirmToClearData : function(aCanBeIgnored)
+	confirmToClearData : function(aCanBeIgnored) 
 	{
 		return this.service.PromptService.confirmEx(
 				window,
@@ -1633,4 +1774,4 @@ if (!window.TabbrowserServiceModules)
 if (TabbrowserSessionManager.enabled)
 	TabbrowserServiceModules.push(TabbrowserSessionManager);
 }
- 
+ 
\ No newline at end of file
