@@ -53,6 +53,10 @@ function initExtraDialog()
 
 		document.getElementById('TextZoom').value = 'textZoom' in gInfo ? Math.min(Math.max(Number(gInfo.textZoom), TabbrowserService.ZOOM_MIN), TabbrowserService.ZOOM_MAX) : 100 ;
 	}
+
+	var title = document.documentElement.getAttribute('title').replace(/%s/g, TS.getNameForBookmark(gBookmarkID));
+	document.documentElement.setAttribute('title', title);
+	document.title = title;
 }
 
 function initCheckbox(aID, aFlag)
