@@ -17,15 +17,6 @@ pref("browser.tabs.extensions.auto_cleanUp_count", 0);
 pref("browser.tabs.extensions.window_auto_close_timeout", false);
 
 
-/*
-	FALSE : "multi-row tabs" and "rearrangable tabs" are exclusive.
-	TRUE  : you can rearrange tabs even if the tab bar is multi-row.
-		Default value is false, because rearranged tabs in multi-row
-		tab bar make Mozilla crash.
-*/
-pref("browser.tabs.extensions.use_multirow_rearrangable_tabs", false);
-
-
 
 pref("browser.tabs.extensions.tab_menu.show",           true);
 pref("browser.tabs.extensions.prevent_same_uri_tab",    false);
@@ -55,19 +46,22 @@ pref("browser.tabs.extensions.window_hook_mode",            0);
 pref("browser.tabs.extensions.startup.page",               0);
 
 pref("browser.tabs.extensions.clear_location_bar",         true);
-// to close windows with several tabs: -1 = ask always, 0 = allow, 1 = forbid
-pref("browser.tabs.extensions.cancel_windowclose",         -1);
+/* to close windows with several tabs:
+	-1 = ask always
+	0  = allow (close all tabs and the window)
+	1  = disallow (don't close window when several tabs are open)
+	10 = close the current tab instead of the window
+*/
+pref("browser.tabs.extensions.window_close.behavior",      -1);
+pref("browser.tabs.extensions.window_close.behavior.confirmOnlyForMultipleTabs", true);
 pref("browser.tabs.extensions.close_only_tab",             false);
 
 
-pref("browser.tabs.opentabfor.sarchbar",                    true);
-pref("browser.tabs.opentabfor.bookmarks",                   true);
 pref("browser.tabs.opentabfor.bookmarks_folder_as_group",   true);
-pref("browser.tabs.opentabfor.history",                     true);
-pref("browser.tabs.opentabfor.linkclick",                   false);
 pref("browser.tabs.opentabfor.windowopen",                  false);
 
 pref("browser.tabs.extensions.livemark.behavior.onMiddleClick", 1);
+pref("browser.tabs.extensions.livemark.behavior.onItemClick",   -1);
 pref("browser.tabs.extensions.platform_native.behavior",        0);
 pref("browser.tabs.extensions.platform_native.allow_window_for_homepage", true);
 
@@ -86,6 +80,8 @@ pref("browser.tabs.extensions.tab_scroller",         0);
 pref("browser.tabs.extensions.tabbar_max_row",       3);
 pref("browser.tabs.extensions.show_blankspaces",     false);
 pref("browser.tabs.extensions.switch_tabs_by_wheel", false);
+pref("browser.tabs.extensions.switch_tabs_by_wheel.count", 1);
+pref("browser.tabs.extensions.switch_tabs_by_wheel.roop",  true);
 /*
 	0 = hide only tabbar
 	1 = unload the tab
@@ -96,8 +92,13 @@ pref("browser.tabs.extensions.switch_tabs_by_wheel", false);
 pref("browser.tabs.extensions.last_tab_closing",     1);
 pref("browser.tabs.extensions.limit.number",         0);
 pref("browser.tabs.extensions.limit.overflow",       true);
+pref("browser.tabs.extensions.tabbar.smooth_scrolling",          true);
+pref("browser.tabs.extensions.tabbar.smooth_scrolling.timeout",  200);
+pref("browser.tabs.extensions.tabbar.smooth_scrolling.interval", 10);
 
 /*
+	-1  = show context menu (only for right click)
+
 	0   = none
 	1   = New Tab
 	2   = Reload Tab
@@ -136,8 +137,9 @@ pref("browser.tabs.extensions.limit.overflow",       true);
 	301 = Block Referrer from All Tabs
 	302 = Auto Reload for All Tabs
 */
-pref("browser.tabs.extensions.tabbar_ondblclick",               1);
-pref("browser.tabs.extensions.tabbar_onmiddleclick",            113);
+pref("browser.tabs.extensions.tabbar_ondblclick",    1);
+pref("browser.tabs.extensions.tabbar_onmiddleclick", 113);
+pref("browser.tabs.extensions.tabbar_onrightclick",  -1);
 
 /* If you set to "true", following shortcuts are available:
 	Shift+Alt+Up   : Focus to the previously selected tab
@@ -160,6 +162,7 @@ pref("browser.tabs.extensions.show_progress",        true);
 pref("browser.tabs.extensions.show_closebox.tab",       -1);
 pref("browser.tabs.extensions.show_closebox.tab.delay", 500);
 pref("browser.tabs.extensions.show_closebox.tab.hide_delay", -1); // -1: inherit
+pref("browser.tabs.extensions.show_closebox.tab.appearance", "builtin");
 pref("browser.tabs.extensions.show_link_text_as_label",             true);
 pref("browser.tabs.extensions.show_link_text_as_label_permanently", false);
 // 0 = start, 1 = center, 2 = end
@@ -171,28 +174,50 @@ pref("browser.tabs.extensions.tabs_min_width",       30);
 pref("browser.tabs.extensions.tabs_max_width",       250);
 // 0 = in left edge, 1 = left, 2 = right, 3 = in right edge
 pref("browser.tabs.extensions.open_tab_in",          3);
-pref("browser.tabs.extensions.open_tab_in_link",     -1); // same to above
+// -1 = same to above
+pref("browser.tabs.extensions.open_tab_in_link",     -1);
 // if true, the behavior of tab dragging/dropping goes back to the old behavior.
 pref("browser.tabs.extensions.dragdrop.only_load_uri", false);
 
 // same to "browser.tabs.extensions.tabbar_on***"
-pref("browser.tabs.extensions.ondblclick",           0);
-pref("browser.tabs.extensions.onmiddleclick",        4);
+pref("browser.tabs.extensions.ondblclick",    0);
+pref("browser.tabs.extensions.onmiddleclick", 4);
+pref("browser.tabs.extensions.onrightclick",  -1);
 
 pref("browser.tabs.extensions.slow_down_autoreload_in_background.enabled", false);
 pref("browser.tabs.extensions.slow_down_autoreload_in_background.rate", 5);
 
 
-pref("browser.tabs.opentabfor.urlbar_always",              false);
-pref("browser.tabs.opentabfor.searchbar_always",           false);
-pref("browser.tabs.opentabfor.anylink",                    false);
+/*
+opentabfor behavior:
+	-1 = no special operation (no reaction or parse normally)
+	0  = open in current tab
+	1  = open in new active tab
+	2  = open in new background tab
+*/
+pref("browser.tabs.opentabfor.urlbar.behavior",                    0);
+pref("browser.tabs.opentabfor.urlbar.foreignDomainBehavior",       -1);
+pref("browser.tabs.opentabfor.urlbar.modifierKeyEnterBehavior",    1);
+pref("browser.tabs.opentabfor.searchbar.behavior",                 0);
+pref("browser.tabs.opentabfor.searchbar.foreignDomainBehavior",    -1);
+pref("browser.tabs.opentabfor.searchbar.modifierKeyEnterBehavior", 1);
+pref("browser.tabs.opentabfor.contextsearch.behavior",             -1);
+pref("browser.tabs.opentabfor.contextsearch.useSearchBox",         false);
+pref("browser.tabs.opentabfor.links.behavior",                     0);
+pref("browser.tabs.opentabfor.links.lockedBehavior",               1);
+pref("browser.tabs.opentabfor.links.targetBehavior",               -1);
+pref("browser.tabs.opentabfor.links.middleClickBehavior",          1);
+pref("browser.tabs.opentabfor.links.outerBehavior",                1);
 // 0 = disable, 1 = different domain, 2 = different user or domain
-pref("browser.tabs.opentabfor.outerlink.level",            0);
-pref("browser.tabs.opentabfor.outerlink.ignoreMiddleClick", true);
-pref("browser.tabs.opentabfor.anybookmark",                false);
-pref("browser.tabs.opentabfor.anyhistory",                 false);
+pref("browser.tabs.opentabfor.outerlink.level",                    1);
+pref("browser.tabs.opentabfor.bookmarks.behavior",                 0);
+pref('browser.tabs.opentabfor.bookmarks.middleClickBehavior',      1);
+pref("browser.tabs.opentabfor.history.behavior",                   0);
+pref("browser.tabs.opentabfor.history.middleClickBehavior",        1);
+pref("browser.tabs.opentabfor.goToHistoryIndex.behavior",          0);
+pref("browser.tabs.opentabfor.goToHistoryIndex.middleClickBehavior", 2);
 
-pref("browser.tabs.extensions.view_source_tab",            false);
+pref("browser.tabs.extensions.view_source_tab",                    false);
 
 
 
@@ -221,14 +246,9 @@ pref("browser.tabs.extensions.bookmarks.save_permissions",   true);
 pref("browser.tabs.extensions.bookmarks.save_textZoom",      true);
 
 
-pref("browser.tabs.extensions.loadInBackgroundLinks",       false);
-pref("browser.tabs.extensions.loadInBackgroundMiddleClick", false);
-pref("browser.tabs.extensions.loadInBackgroundBookmarks",   false);
 pref("browser.tabs.extensions.loadInBackgroundHistory",     false);
-pref("browser.tabs.extensions.loadInBackgroundLocationBar", false);
-pref("browser.tabs.extensions.loadInBackgroundSearchBar",   false);
 pref("browser.tabs.extensions.loadInBackgroundJS",          false);
-pref("browser.tabs.extensions.loadInBackgroundPlatformNative",      false);
+pref("browser.tabs.extensions.loadInBackgroundPlatformNative", false);
 pref("browser.tabs.extensions.loadInBackgroundViewSource",  false);
 
 pref("browser.tabs.extensions.loadInBackgroundWindow",       false);
@@ -308,3 +328,21 @@ pref("browser.tabs.extensions.bookmarkgroup_behavior",            0);
 
 
 pref("browser.tabs.extensions.autoreload.lastInterval", 0);
+
+
+
+
+
+
+pref("browser.tabs.extensions.bypass_referrerblocker", false);
+pref("browser.tabs.extensions.bypass_referrerblocker.list", "ime.nu/|ime.st/|pinktower.com/");
+
+
+
+pref("browser.tabs.extensions.preventToModifyWindowState.timeout", 3000);
+
+
+
+// default settings from firefox.js, all.js, etc.
+pref("browser.tabs.loadInBackground", true);
+pref("browser.tabs.autoHide", true);
