@@ -13,6 +13,17 @@ function advancedPrefs(aURI, aData)
 			switch (aData[i].node.localName)
 			{
 				case 'checkbox':
+					switch (typeof aData[i].newValue)
+					{
+						case 'string':
+							aData[i].newValue = aData[i].newValue == 'true';
+							break;
+						case 'number':
+							aData[i].newValue = aData[i].newValue != 0;
+							break;
+						default:
+							break;
+					}
 					aData[i].node.checked = aData[i].newValue;
 					break;
 				case 'textbox':
@@ -138,6 +149,23 @@ function getModifiedValue(aKey, aPanel)
 
 
 
+function initNewTypeLabel()
+{
+	if (TabbrowserService.isNewTypeBrowser) {
+		var newTypeLabels = document.getElementsByAttribute('newtypelabel-for', '*');
+		var node;
+
+		for (var i = 0; i < newTypeLabels.length; i++)
+		{
+			node = document.getElementById(newTypeLabels[i].getAttribute('newtypelabel-for'));
+			if (!node) continue;
+			node.setAttribute('label', newTypeLabels[i].getAttribute('value'));
+			if (node.localName != 'caption')
+				node.setAttribute('flex', 1);
+		}
+	}
+}
+
 function initMacLabel()
 {
 	if (navigator.platform.match(/Mac/)) {
@@ -149,7 +177,8 @@ function initMacLabel()
 			node = document.getElementById(macLabels[i].getAttribute('maclabel-for'));
 			if (!node) continue;
 			node.setAttribute('label', macLabels[i].getAttribute('value'));
-			node.setAttribute('flex', 1);
+			if (node.localName != 'caption')
+				node.setAttribute('flex', 1);
 		}
 	}
 }
