@@ -1,14 +1,13 @@
-var version     = '1.11.2004111302',
+var version     = '1.14.2005040701',
 	displayName = 'Tabbrowser Extensions',
 	appName     = 'tabextensions',
 	author      = 'SHIMODA Hiroshi',
 	hasLangPack = true,
 	hasJLP      = true,
 	hasSkin     = true,
-	bindingsName = 'tabextensionsBindings',
-	widgetsName  = 'tabextensionsWidgets',
 	options     = [
-					'sessionManager'
+					'sessionManager',
+					'ctrlPopup'
 				];
 
 
@@ -66,25 +65,6 @@ else {
 
 		registerChrome(contentFlag, folder, 'content/'+appName+'/');
 
-		if (('widgetsName' in this && widgetsName) ||
-			('bindingsName' in this && bindingsName)) {
-			if (
-				isNewType &&
-				(
-					Install.buildID < 2003111900 &&
-					!File.exists(getFolder('Program', 'firefox.exe')) &&
-					!File.exists(getFolder('Program', 'firefox-bin.exe')) &&
-					!File.exists(getFolder('Program', 'firefox')) &&
-					!File.exists(getFolder('Program', 'firefox-bin'))
-				)
-				) {
-				if (widgetsName)
-					registerChrome(contentFlag, folder, 'content/'+widgetsName+'/');
-			}
-			else if (bindingsName)
-					registerChrome(contentFlag, folder, 'content/'+bindingsName+'/');
-		}
-
 
 		if ('options' in this && options.length) {
 			for (i = 0; i < options.length; i++)
